pub trait SingleExtensionComputer<T>where
T: LabelType,{
// Required method
fn compute_one_extension(&mut self) -> Option<Vec<&Argument<T>>>;
}Expand description
A trait for solvers able to compute an extension.
Required Methods
Sourcefn compute_one_extension(&mut self) -> Option<Vec<&Argument<T>>>
fn compute_one_extension(&mut self) -> Option<Vec<&Argument<T>>>
Computes a single extension.
In case the problem admits no extension, Option::None is return. In case an extension is found, it is returned as a vector of arguments.